@@ -1,4 +1,3 @@
-
 /*
  *  soldevice.h
  *
@@ -49,71 +48,75 @@ class QVListLayout;
 
 class SolDevice : public QTreeWidgetItem
 {
-  
-  public:
+public:
     SolDevice(const Solid::DeviceInterface::Type &);
     SolDevice(const Solid::DeviceInterface::Type &, const QString &);
     SolDevice(QTreeWidgetItem *);
     SolDevice(QTreeWidgetItem *, const Solid::Device &);
-    
+
     QIcon deviceIcon() const;
     Solid::Device *device();
     Solid::DeviceInterface::Type deviceType() const;
-    
-    template <class IFace> const IFace *interface() 
-    {
-      if(deviceSet)
-      {
-	IFace *dev = tiedDevice.as<const IFace>();
-	if(!dev)
-	{
-	  qDebug() << "Device unable to be cast to correct device";
-	}
-	return dev;
-      } else {
-	return NULL;
-      }
-    }
-    
-    template <class IFace> const IFace *interface(const Solid::Device &device) 
-    {
-	IFace *dev = device.as<const IFace>();
-	if(!dev) {
-	  qDebug() << "Device unable to be cast to correct device";
-	}
-	return dev;
-    }
-    
-    template <class IFace> void createDeviceChildren(
-      QTreeWidgetItem *treeParent, const QString &parentUid, const Solid::DeviceInterface::Type &type) 
-    {  
-      const QList<Solid::Device> list = Solid::Device::listFromType(type, parentUid);
 
-      foreach(const Solid::Device &dev, list)
-      {
-	new IFace(treeParent,dev);
-      }
-    }   
+    template<class IFace> const IFace *interface()
+    {
+        if (deviceSet) {
+            IFace *dev = tiedDevice.as<const IFace>();
+            if (!dev) {
+                qDebug() << "Device unable to be cast to correct device";
+            }
+            return dev;
+        } else {
+            return nullptr;
+        }
+    }
+
+    template<class IFace> const IFace *interface(const Solid::Device &device)
+    {
+        IFace *dev = device.as<const IFace>();
+        if (!dev) {
+            qDebug() << "Device unable to be cast to correct device";
+        }
+        return dev;
+    }
+
+    template<class IFace> void createDeviceChildren(
+        QTreeWidgetItem *treeParent, const QString &parentUid,
+        const Solid::DeviceInterface::Type &type)
+    {
+        const QList<Solid::Device> list = Solid::Device::listFromType(type, parentUid);
+
+        foreach (const Solid::Device &dev, list) {
+            new IFace(treeParent, dev);
+        }
+    }
 
     void setDeviceIcon(const QIcon &);
     void setDeviceToolTip(const QString &);
 
     virtual QVListLayout *infoPanelLayout();
-    virtual void addItem(Solid::Device dev) { new SolDevice(this,dev); };
-    virtual void refreshName() { setDefaultDeviceText(); };
-   
+    virtual void addItem(const Solid::Device &dev)
+    {
+        new SolDevice(this, dev);
+    }
+
+    virtual void refreshName()
+    {
+        setDefaultDeviceText();
+    }
+
     QString udi() const;
     bool isDeviceSet();
-    
-  protected:
-    
+
+protected:
+
     void setDeviceText(const QString &);
-    
+
     virtual void setDefaultDeviceToolTip();
-    virtual void setDefaultDeviceText(); 
+    virtual void setDefaultDeviceText();
     virtual void setDefaultDeviceIcon();
-    virtual void setDefaultListing(const Solid::DeviceInterface::Type &); 
-    
+    virtual void setDefaultListing(const Solid::DeviceInterface::Type &);
+
     bool deviceSet;
     QVListLayout *deviceInfoLayout;
     Solid::DeviceInterface::Type deviceTypeHolder;
